@@ -78,11 +78,6 @@ var _ = Describe("[vendor:cnv-qe@redhat.com][level:component]DataVolume tests",
 		return fmt.Sprintf(utils.VcenterURL, f.CdiInstallNs)
 	}
 
-	// Invalid (malicious) QCOW images:
-	// An image that causes qemu-img to allocate 152T (original image is 516 bytes)
-	invalidQcowLargeSizeURL := func() string {
-		return InvalidQcowImagesURL() + "invalid-qcow-large-size.img"
-	}
 	// An image that causes qemu-img info to output half a million lines of JSON
 	invalidQcowLargeJSONURL := func() string {
 		return InvalidQcowImagesURL() + "invalid-qcow-large-json.img"
@@ -211,7 +206,6 @@ var _ = Describe("[vendor:cnv-qe@redhat.com][level:component]DataVolume tests",
 			readyCondition   *cdiv1.DataVolumeCondition
 			boundCondition   *cdiv1.DataVolumeCondition
 			runningCondition *cdiv1.DataVolumeCondition
-			skipOpenshift    bool
 		}
 
 		createImageIoDataVolume := func(dataVolumeName, size, url string) *cdiv1.DataVolume {
@@ -250,10 +244,7 @@ var _ = Describe("[vendor:cnv-qe@redhat.com][level:component]DataVolume tests",
 			return utils.NewDataVolumeForUpload(dataVolumeName, size)
 		}
 
-		table.DescribeTable("should", func(args dataVolumeTestArguments) {
-			if IsOpenshift(f.K8sClient) && args.skipOpenshift {
-				Skip("Test not expected to pass on OpenShift")
-			}
+		testDataVolume := func(args dataVolumeTestArguments) {
 			// Have to call the function in here, to make sure the BeforeEach in the Framework has run.
 			dataVolume := args.dvFunc(args.name, args.size, args.url())
 			startTime := time.Now()
@@ -323,7 +314,9 @@ var _ = Describe("[vendor:cnv-qe@redhat.com][level:component]DataVolume tests",
 					return false
 				}, timeout, pollingInterval).Should(BeTrue())
 			}
-		},
+		}
+
+		table.DescribeTable("should", testDataVolume,
 			table.Entry("[rfe_id:1115][crit:high][test_id:1357]succeed creating import dv with given valid url", dataVolumeTestArguments{
 				name:             "dv-http-import",
 				size:             "1Gi",
@@ -396,32 +389,6 @@ var _ = Describe("[vendor:cnv-qe@redhat.com][level:component]DataVolume tests",
 					Message: "Unable to connect to http data source: expected status code 200, got 404. Status: 404 Not Found",
 					Reason:  "Error",
 				}}),
-			table.Entry("[rfe_id:1120][crit:high][posneg:negative][test_id:2555]fail creating import dv: invalid qcow large size", dataVolumeTestArguments{
-				name:         "dv-invalid-qcow-large-size",
-				size:         "1Gi",
-				url:          invalidQcowLargeSizeURL,
-				dvFunc:       utils.NewDataVolumeWithHTTPImport,
-				errorMessage: "Unable to process data: Invalid format qcow for image",
-				eventReason:  "Error",
-				phase:        cdiv1.ImportInProgress,
-				readyCondition: &cdiv1.DataVolumeCondition{
-					Type:   cdiv1.DataVolumeReady,
-					Status: v1.ConditionFalse,
-				},
-				boundCondition: &cdiv1.DataVolumeCondition{
-					Type:    cdiv1.DataVolumeBound,
-					Status:  v1.ConditionTrue,
-					Message: "PVC dv-invalid-qcow-large-size Bound",
-					Reason:  "Bound",
-				},
-				runningCondition: &cdiv1.DataVolumeCondition{
-					Type:    cdiv1.DataVolumeRunning,
-					Status:  v1.ConditionFalse,
-					Message: "Unable to process data: Invalid format qcow for image",
-					Reason:  "Error",
-				},
-				skipOpenshift: true,
-			}),
 			table.Entry("[rfe_id:1120][crit:high][posneg:negative][test_id:2554]fail creating import dv: invalid qcow large json", dataVolumeTestArguments{
 				name:         "dv-invalid-qcow-large-json",
 				size:         "1Gi",
@@ -782,6 +749,47 @@ var _ = Describe("[vendor:cnv-qe@redhat.com][level:component]DataVolume tests",
 				}}),
 		)
 
+		// Similar to previous table, but with additional cleanup steps
+		table.DescribeTable("should", func(args dataVolumeTestArguments) {
+			configMap, err := RunKubectlCommand(f, "get", "configmap", "-o", "yaml", "-n", f.CdiInstallNs, common.VddkConfigMap)
+			Expect(err).ToNot(HaveOccurred())
+
+			_, err = RunKubectlCommand(f, "delete", "configmap", "-n", f.CdiInstallNs, common.VddkConfigMap)
+			Expect(err).ToNot(HaveOccurred())
+
+			defer func() {
+				command := CreateKubectlCommand(f, "create", "-n", f.CdiInstallNs, "-f", "-")
+				command.Stdin = strings.NewReader(configMap)
+				err := command.Run()
+				Expect(err).ToNot(HaveOccurred())
+			}()
+
+			testDataVolume(args)
+		},
+			table.Entry("[test_id:5079]should fail with \"AwaitingVDDK\" reason when VDDK credentials config map is not present", dataVolumeTestArguments{
+				name:             "dv-awaiting-vddk",
+				size:             "1Gi",
+				url:              vcenterURL,
+				dvFunc:           createVddkDataVolume,
+				eventReason:      common.AwaitingVDDK,
+				phase:            cdiv1.ImportScheduled,
+				checkPermissions: false,
+				readyCondition: &cdiv1.DataVolumeCondition{
+					Type:   cdiv1.DataVolumeReady,
+					Status: v1.ConditionFalse,
+				},
+				boundCondition: &cdiv1.DataVolumeCondition{
+					Type:    cdiv1.DataVolumeBound,
+					Status:  v1.ConditionFalse,
+					Message: fmt.Sprintf("waiting for %s configmap for VDDK image", common.VddkConfigMap),
+					Reason:  common.AwaitingVDDK,
+				},
+				runningCondition: &cdiv1.DataVolumeCondition{
+					Type:   cdiv1.DataVolumeRunning,
+					Status: v1.ConditionFalse,
+				}}),
+		)
+
 		It("[test_id:4961]should handle a pre populated PVC", func() {
 			By(fmt.Sprintf("initializing source PVC %s", dataVolumeName))
 			sourcePodFillerName := fmt.Sprintf("%s-filler-pod", dataVolumeName)
@@ -997,6 +1005,7 @@ var _ = Describe("[vendor:cnv-qe@redhat.com][level:component]DataVolume tests",
 		verifyAnnotations := func(pod *v1.Pod) {
 			By("verifying passed annotation")
 			Expect(pod.Annotations[controller.AnnPodNetwork]).To(Equal("net1"))
+			Expect(pod.Annotations[controller.AnnPodSidecarInjection]).To(Equal(controller.AnnPodSidecarInjectionDefault))
 			By("verifying non-passed annotation")
 			Expect(pod.Annotations["annot1"]).ToNot(Equal("value1"))
 		}
